@@ -17,6 +17,8 @@
 	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
+#include <sys/types.h>
+
 #include "extras.h"
 #include "miscutils.h"
 #include "mmainwindow.h"
@@ -91,7 +93,7 @@ Extras::Extras()
 	connect(_menu, SIGNAL(activated(int)), SLOT(slotActivated(int)));
 }
 
-// TODO: 0.9: recent items
+// TODO: 2.0: recent items
 void Extras::buildMenu(KPopupMenu *parentMenu, const QString &subdir)
 {
 	int id;
@@ -228,7 +230,7 @@ void Extras::setAction(const QString &fileToExecute, const QString &description)
 	else
 	{
 		_button->setText(getActionDescription());
-// TODO: 0.9: selected item icon
+// TODO: 2.0: selected item icon
 		_button->setIconSet(ks_actions->getIcon(Action::Extras));
 	}
 }
@@ -239,16 +241,14 @@ void Extras::slotModify()
 {
 	KMessageBox::information(
 		0,
-		"<qt>" +
-		i18n("Use context menu to add/edit/remove links.") +
-		"<ul>" +
-		"<li>" + i18n("Use <b>Context Menu</b> " \
-			"to create a new link to application") + "</li>" +
-		"<li>" + i18n("Use <b>Create New|Folder...</b> " \
-			"to create a new submenu") + "</li>" +
-		"<li>" + i18n("Use <b>Properties</b> " \
-			"to change icon, name, or comment") + "</li>" +
-		"</ul></qt>",
+		MiscUtils::HTML(
+			i18n("Use context menu to add/edit/remove links.") +
+			"<ul>" +
+				"<li>" + i18n("Use <b>Context Menu</b> to create a new link to application") + "</li>" +
+				"<li>" + i18n("Use <b>Create New|Folder...</b> to create a new submenu") + "</li>" +
+				"<li>" + i18n("Use <b>Properties</b> to change icon, name, or comment") + "</li>" +
+			"</ul>"
+		),
 		i18n("Extras"), // title
 		"ModifyExtras" // config key
 	);
