@@ -19,6 +19,7 @@
 
 #include "actions.h"
 #include "links.h"
+#include "miscutils.h"
 
 #include <qcombobox.h>
 #include <qfile.h>
@@ -36,57 +37,64 @@
 // public
 
 Links::Links(QWidget *parent)
-	: QGrid(2, parent, "Links")
+	: QVBox(parent, "Links")
 {
 	setSpacing(5);
 	int alignment = AlignVCenter;
 	alignment |= kapp->reverseLayout() ? AlignLeft : AlignRight;
 
+
 	// location
-	QLabel *l_location = new QLabel(i18n("Select a location where to create the link:"), this);
+	QHBox *w_location = new QHBox(this);
+	w_location->setSpacing(5);
+	QLabel *l_location = new QLabel(i18n("Location where to create the link:"), w_location);
 	l_location->setAlignment(alignment);
-	cb_location = new QComboBox(this, "QComboBox::cb_location");
+	cb_location = new QComboBox(w_location, "QComboBox::cb_location");
 	cb_location->setFocusPolicy(StrongFocus);
 	cb_location->insertItem(SmallIcon("desktop"), i18n("Desktop"));
 	cb_location->insertItem(SmallIcon("kmenu"), i18n("K Menu"));
 	l_location->setBuddy(cb_location);
+	connect(cb_location, SIGNAL(activated(int)), SLOT(slotActivated(int)));
 
 	// type
-	QLabel *l_type = new QLabel(i18n("Select a type of the link:"), this);
+	QHBox *w_type = new QHBox(this);
+	w_type->setSpacing(5);
+	QLabel *l_type = new QLabel(i18n("Type of the link:"), w_type);
 	l_type->setAlignment(alignment);
-	cb_type = new QComboBox(this, "QComboBox::cb_type");
+	cb_type = new QComboBox(w_type, "QComboBox::cb_type");
 	cb_type->setFocusPolicy(StrongFocus);
-	cb_type->insertItem(kapp->miniIcon(), i18n("KShutDown"));
+	cb_type->insertItem(kapp->miniIcon(), "KShutDown");
+
+	// NOTE: slotAddRemoveLink()
 	cb_type->insertItem(SmallIcon("exit"), i18n("Standard Logout Dialog"));
+
 	cb_type->insertItem(ks_actions->getIcon(Action::ShutDown), ks_actions->getName(Action::ShutDown));
 	cb_type->insertItem(ks_actions->getIcon(Action::Reboot), ks_actions->getName(Action::Reboot));
 	cb_type->insertItem(ks_actions->getIcon(Action::LockScreen), ks_actions->getName(Action::LockScreen));
 	cb_type->insertItem(ks_actions->getIcon(Action::Logout), ks_actions->getName(Action::Logout));
 	l_type->setBuddy(cb_type);
+	connect(cb_type, SIGNAL(activated(int)), SLOT(slotActivated(int)));
 
-	// create link
-	KPushButton *b_createLink = new KPushButton(SmallIcon("filenew"), i18n("Create Link"), this, "KPushButton::b_createLink");
-	connect(b_createLink, SIGNAL(clicked()), SLOT(slotCreateLink()));
+	// add/remove link
+	b_addRemoveLink = new KPushButton(this, "KPushButton::b_addRemoveLink");
+	connect(b_addRemoveLink, SIGNAL(clicked()), SLOT(slotAddRemoveLink()));
 
-// TODO: 0.9: disable button if file does not exist
-	// remove link
-	KPushButton *b_removeLink = new KPushButton(SmallIcon("editdelete"), i18n("Remove Link"), this, "KPushButton::b_removeLink");
-	connect(b_removeLink, SIGNAL(clicked()), SLOT(slotRemoveLink()));
+	updateAddRemoveButton();
 }
 
-void Links::createLink(const QString &path, const QString &command, const QString &icon, const QString &name)
+void Links::createLink(const QString &path, const QString &command, const QString &icon, const QString &name, const QString &comment)
 {
 	if (path.isNull())
 		return;
 
-// FIXME: 0.9: description/comment
 	KDesktopFile *df = new KDesktopFile(path);
 	df->setGroup("Desktop Entry");
+	df->writeEntry("Comment", comment);
 	df->writeEntry("Encoding", "UTF-8");
 	df->writeEntry("Exec", command);
+	df->writeEntry("GenericName", i18n("System Shut Down Utility"));
 	df->writeEntry("Icon", icon);
-	if (!name.isNull())
-		df->writeEntry("Name", name);
+	df->writeEntry("Name", name);
 	df->writeEntry("StartupNotify", "false");
 	df->writeEntry("Type", "Application");
 	delete df;
@@ -95,7 +103,7 @@ void Links::createLink(const QString &path, const QString &command, const QStrin
 	{
 		KMessageBox::error(
 			0,
-			"<qt>" + i18n("Could not create file <b>%1</b>!").arg(path) + "</qt>"
+			MiscUtils::HTML(i18n("Could not create file <b>%1</b>!").arg(path))
 		);
 	}
 }
@@ -106,7 +114,7 @@ void Links::removeLink(const QString &path)
 	{
 		KMessageBox::error(
 			0,
-			"<qt>" + i18n("Could not remove file <b>%1</b>!").arg(path) + "</qt>"
+			MiscUtils::HTML(i18n("Could not remove file <b>%1</b>!").arg(path))
 		);
 	}
 }
@@ -168,19 +176,35 @@ QString Links::getCurrentTypeIcon() const
 	}
 }
 
+void Links::updateAddRemoveButton() {
+	if (QFile::exists(getCurrentLocationPath())) {
+		b_addRemoveLink->setIconSet(SmallIcon("editdelete"));
+		b_addRemoveLink->setText(i18n("Remove Link"));
+	}
+	else {
+		b_addRemoveLink->setIconSet(SmallIcon("filenew"));
+		b_addRemoveLink->setText(i18n("Add Link"));
+	}
+}
+
 // private slots
 
-void Links::slotCreateLink()
-{
-	createLink(
-		getCurrentLocationPath(),
-		getCurrentTypeCommand(),
-		getCurrentTypeIcon(),
-		(cb_type->currentItem() == 1 /* evil */) ? i18n("Logout") : cb_type->currentText()
-	);
+void Links::slotActivated(int/* index*/) {
+	updateAddRemoveButton();
 }
 
-void Links::slotRemoveLink()
-{
-	removeLink(getCurrentLocationPath());
+void Links::slotAddRemoveLink() {
+	if (QFile::exists(getCurrentLocationPath())) {
+		removeLink(getCurrentLocationPath());
+	}
+	else {
+		createLink(
+			getCurrentLocationPath(),
+			getCurrentTypeCommand(),
+			getCurrentTypeIcon(),
+			(cb_type->currentItem() == 1) ? i18n("Logout") : cb_type->currentText(),
+			cb_type->currentText()
+		);
+	}
+	updateAddRemoveButton();
 }
