@@ -31,7 +31,7 @@
 
 // 0.1.x, 0.3.x, etc - Unstable, Beta
 // 0.2.x, 0.4.x, etc - Stable
-QString version = "0.8";
+QString version = "1.0";
 
 KAboutData aboutData(
 	"kshutdown", // internal name
@@ -66,7 +66,7 @@ static KCmdLineOptions options[] =
 	{ "default", I18N_NOOP("Disable test mode"), 0 },
 	{ "+[time]", I18N_NOOP("Time; Examples: 01:30 - absolute time (HH:MM); " \
 		"10 - number of minutes to wait from now"), 0 },
-	{ 0, 0, 0 }
+	KCmdLineLastOption
 };
 
 /** @short KShutDown application. */
@@ -111,12 +111,22 @@ private:
 
 int KShutDownApplication::newInstance()
 {
+	// autostart
+	if (kapp->isRestored()) {
+		KConfig *config = kapp->config();
+		config->setGroup("KShutDown");
+		if (!config->readBoolEntry("Autostart", false)) {
+			quit();
+
+			return 0;
+		}
+	}
+
 	static bool doShow = false;
 	bool doRaise = ks_main;
 
 	// create main window (only one)
-	if (!ks_main)
-	{
+	if (!ks_main) {
 		(void)new MMainWindow();
 		kapp->setMainWidget(ks_main);
 		connect(
@@ -129,8 +139,7 @@ int KShutDownApplication::newInstance()
 	int retval = doProcessArgs(args);
 	args->clear();
 
-	if (MSystemTray::mode() != MSystemTray::Always)
-	{
+	if (MSystemTray::mode() != MSystemTray::Always) {
 		ks_main->show();
 		if (doRaise)
 			ks_main->makeVisible();
@@ -139,10 +148,9 @@ int KShutDownApplication::newInstance()
 		return Mode_Ok;
 	}
 
-	if ((retval == Mode_Visible) || (retval == Mode_Hidden)) // gui mode
-	{
-		if ((retval == Mode_Visible) && (!kapp->isRestored() || doShow))
-		{
+	// gui mode
+	if ((retval == Mode_Visible) || (retval == Mode_Hidden)) {
+		if ((retval == Mode_Visible) && (!kapp->isRestored() || doShow)) {
 			ks_main->show();
 			if (doRaise)
 				ks_main->makeVisible();
@@ -157,17 +165,14 @@ int KShutDownApplication::newInstance()
 
 // private
 
-int KShutDownApplication::doExecAction(const Action::Type action)
-{
+int KShutDownApplication::doExecAction(const Action::Type action) {
 	if (!ks_main)
 		return Mode_Error;
 
 	// use time arg.
-	if (timeArgIsValid)
-	{
+	if (timeArgIsValid) {
 		ks_main->cancel(); // cancel action (if any)
-		if (!now)
-		{
+		if (!now) {
 			ks_main->setAction(action);
 			ks_main->start(_confirm);
 
@@ -175,13 +180,11 @@ int KShutDownApplication::doExecAction(const Action::Type action)
 		}
 	}
 
-	if (_confirm)
-	{
+	if (_confirm) {
 		if (ks_actions->execConfirm(action))
 			return Mode_Ok;
 	}
-	else
-	{
+	else {
 		if (ks_actions->exec(action, action != Action::LockScreen))
 			return Mode_Ok;
 	}
@@ -190,8 +193,7 @@ int KShutDownApplication::doExecAction(const Action::Type action)
 	return Mode_Error;
 }
 
-int KShutDownApplication::doProcessArgs(const KCmdLineArgs *args)
-{
+int KShutDownApplication::doProcessArgs(const KCmdLineArgs *args) {
 	if (!ks_main)
 		return Mode_Error;
 
@@ -205,50 +207,40 @@ int KShutDownApplication::doProcessArgs(const KCmdLineArgs *args)
 	bool absoluteTime = false;
 	int minutes = 0;
 	QDateTime dt = QDateTime::currentDateTime();
-	if (args->count())
-	{
+	if (args->count()) {
 		timeArg = args->arg(0); // first arg. is a "time" arg.
-		if (!timeArg.isEmpty())
-		{
+		if (!timeArg.isEmpty()) {
 			isTimeArg = true;
 
-			if (timeArg.upper() == "NOW")
-			{
+			if (timeArg.upper() == "NOW") {
 				now = true;
 				timeArgIsValid = true;
 			}
-			else
-			{
+			else {
 				bool ok = false;
 				minutes = timeArg.toInt(&ok); // MM?
-				if (ok)
-				{
-					if (minutes == 0)
-					{
+				if (ok) {
+					if (minutes == 0) {
 						now = true;
 						timeArgIsValid = true;
 					}
 				}
-				else
-				{
+				else {
 					absoluteTime = true;
-// FIXME: 0.9: AM/PM
+// FIXME: 2.0: AM/PM
 					QTime t = QTime::fromString(timeArg);
-					if (t.isValid() && !t.isNull()) // HH:MM[:SS]?
-					{
+					if (t.isValid() && !t.isNull()) { // HH:MM[:SS]?
 						ok = true;
 						dt.setTime(t);
 					}
 				}
-				if (!ok || !dt.isValid() || dt.isNull())
-				{
+				if (!ok || !dt.isValid() || dt.isNull()) {
 					KMessageBox::error(
 						0,
-						"<qt>" + i18n("Invalid time: <b>%1</b>").arg(timeArg) + "</qt>"
+						MiscUtils::HTML(i18n("Invalid time: <b>%1</b>").arg(timeArg))
 					);
 				}
-				else
-				{
+				else {
 					timeArgIsValid = true;
 				}
 			}
@@ -264,16 +256,14 @@ int KShutDownApplication::doProcessArgs(const KCmdLineArgs *args)
 		ks_main->setTestMode(false);
 
 	// cancel
-	if (args->isSet("cancel"))
-	{
+	if (args->isSet("cancel")) {
 		ks_main->cancel();
 
 		return Mode_Ok;
 	}
 
 	// standard logout dialog
-	if (args->isSet("standard"))
-	{
+	if (args->isSet("standard")) {
 		kapp->requestShutDown(
 			KApplication::ShutdownConfirmYes,
 			KApplication::ShutdownTypeDefault,
@@ -288,10 +278,8 @@ int KShutDownApplication::doProcessArgs(const KCmdLineArgs *args)
 		return Mode_Error;
 
 	// setup main window
-	if (timeArgIsValid)
-	{
-		if (!now)
-		{
+	if (timeArgIsValid) {
+		if (!now) {
 			if (MiscUtils::isRestricted("tab_time"))
 				return Mode_Error;
 
@@ -339,11 +327,11 @@ int KShutDownApplication::doProcessArgs(const KCmdLineArgs *args)
 
 int main(int argc, char **argv)
 {
-// TODO: 0.9: init on demand?
+// TODO: 2.0: init on demand?
 	aboutData.addCredit("Konrad Twardowski", "Author, Maintainer", "kdtonline@poczta.onet.pl", "http://www.kdtonline.prv.pl/");
 	aboutData.addCredit("Caryn \"Hellchick\" Law", "Female Quake III Arena Announcer Voice Files", "hellchick ( at ) planetquake.com", "http://www.planetquake.com/voxfeminae/");
 	aboutData.addCredit("Arend van Beelen jr.", "Ideas", "", "http://www.liacs.nl/~dvbeelen");
-	aboutData.addCredit("Bram Schoenmakers", "Dutch translation", "bram_s ( at ) softhome.net", "http://home.wanadoo.nl/bram_s");
+	aboutData.addCredit("Bram Schoenmakers", "Dutch translation", "bram_s ( at ) softhome.net");
 	aboutData.addCredit("Charles Barcza", "Hungarian translation, blackPanther-Linux RPM", "kbarcza ( at ) blackpanther.hu", "http://www.blackpanther.hu/");
 	aboutData.addCredit("Daniel Nylander", "Swedish translation");
 	aboutData.addCredit("Elias Probst", "Gentoo ebuilds, German translation", "elias.probst ( at ) gmx.de");
